@@ -1,18 +1,18 @@
 
 /* defs.h
- * 
+ *
  * Copyright (C) 2009 Francesco Abbate
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -32,6 +32,7 @@
 #endif
 
 #define LUA_INDEX_CONVENTION
+#define GSL_SHELL_RELEASE "2.3.1"
 
 #ifdef WIN32
 #ifndef __cplusplus
@@ -45,7 +46,7 @@ typedef int bool;
 #include <stdbool.h>
 #endif
 
-extern char const * const OUT_OF_MEMORY_MSG;
-extern char const * const INVALID_INDEX_MSG;
+#define likely(x)	__builtin_expect(!!(x), 1)
+#define unlikely(x)	__builtin_expect(!!(x), 0)
 
 #endif
